@@ -7,6 +7,7 @@ there are many different ways to initialize SQLALchemy.
 
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
+from decimal import Decimal
 import re
 from datetime import date, datetime
 from sqlalchemy import Table, Column, ForeignKey, Sequence
@@ -17,6 +18,7 @@ from sqlalchemy.orm.dynamic import DynamicAttributeImpl
 from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy.types import Integer, DateTime, Unicode
+from bag import resolve
 from ..web import gravatar_image
 
 # http://docs.sqlalchemy.org/en/latest/orm/session.html#cascades
@@ -56,14 +58,16 @@ def length(attrib):
     return _get_length(col(attrib))
 
 
-def fk(attrib, nullable=False, index=True):
+def fk(attrib, nullable=False, index=True, primary_key=False, doc=None):
     '''Returns a ForeignKey column while automatically setting the type.'''
     column = col(attrib)
-    return Column(column.copy().type, ForeignKey(column),
-                  nullable=nullable, index=index)
+    return Column(column.copy().type, ForeignKey(
+        column, ondelete=None if nullable else 'CASCADE',  # vs 'SET NULL'
+        ), doc=doc, index=index, primary_key=primary_key, nullable=nullable)
 
 
-def fk_rel(cls, backref=None, attrib='id', nullable=False, index=True, cascade=CASC):
+def fk_rel(cls, backref=None, attrib='id', nullable=False, index=True,
+           primary_key=False, cascade=CASC, doc=None):
     '''Returns a ForeignKey column and a relationship,
     while automatically setting the type of the foreign key.
 
@@ -75,12 +79,18 @@ def fk_rel(cls, backref=None, attrib='id', nullable=False, index=True, cascade=C
 
     A backref is created only if you provide its name in the argument.
     ``nullable`` and ``index`` are usually ommited, because these are the
-    default values and they are good. ``cascade`` is 'all, delete-orphan' by
-    default, but you can set it to False. You may also pass an ``attrib``
+    default values and they are good. ``cascade`` is "all, delete-orphan" by
+    default, but you can set it to False, which translates to
+    "save-update, merge". You may also pass an ``attrib``
     which is the column name for the foreign key.
     '''
-    return (fk(getattr(cls, attrib), nullable=nullable, index=index),
-            relationship(cls, backref=_backref(backref, cascade=cascade))
+    if cascade is None:
+        cascade = CASC if nullable else False
+    return (fk(getattr(cls, attrib), nullable=nullable, index=index,
+               primary_key=primary_key, doc=doc),
+            relationship(cls, backref=_backref(
+                backref, cascade=cascade,
+                passive_deletes=False if nullable else True))
             if backref else relationship(cls))
 
 
@@ -121,6 +131,25 @@ def pk(tablename):
                   primary_key=True, autoincrement=True)
 
 
+def is_model_class(val):
+    return hasattr(val, '__base__') and hasattr(val, '__table__')
+
+
+def models_and_tables_in(arg):
+    '''``arg`` may be a resource spec, a module or a dictionary.
+
+    Returns 2 lists containing the model classes and tables in it::
+
+        models, tables = models_and_tables_in(globals())
+    '''
+    if not isinstance(arg, dict):
+        arg = resolve(arg)  # ensure arg is a python module
+        arg = arg.__dict__
+    models = [o for o in arg.values() if is_model_class(o)]
+    tables = [o for o in arg.values() if isinstance(o, Table)]
+    return models, tables
+
+
 def model_property_names(cls, whitelist=None, blacklist=None,
                          include_relationships=True):
     names = (str(n).split('.')[1] for n in cls.__mapper__.iterate_properties)
@@ -170,23 +199,52 @@ class MinimalBase(object):
         return name[0].lower() + \
             re.sub(r'([A-Z])', lambda m: "_" + m.group(0).lower(), name[1:])
 
-    def to_dict(self, blacklist=None, convert_date=False):  # TODO Whitelist
-        """Dumps the properties of the object into a dict for use in json."""
+    def to_dict(self, blacklist=None, whitelist=None, for_json=True):
+        '''Dumps the properties of the object into a dict.'''
         props = {}
-        for key in self.__dict__:
-            if key in (blacklist or self.blacklist) or key.startswith('__') \
-                    or key.startswith('_sa_'):
+        blacklist = self.blacklist if blacklist is None else blacklist
+        keys = whitelist or self.whitelist or (
+            key for key in self.__dict__.keys()
+            if not key.startswith('__') and not key.startswith('_sa_'))
+        for key in keys:
+            if key in blacklist:
                 continue
             obj = getattr(self, key)
-            if isinstance(obj, datetime) or isinstance(obj, date):
-                if convert_date:
-                    props[key] = obj.isoformat()
-                else:
-                    props[key] = obj
+            if for_json and isinstance(obj, datetime) or isinstance(obj, date):
+                props[key] = obj.isoformat()
+            elif for_json and isinstance(obj, Decimal):
+                props[key] = float(str(obj))
             else:
                 props[key] = obj
         return props
     blacklist = ['password']
+    whitelist = None
+
+    def update(self, adict, transient=False):
+        '''Applies the information in the provided dictionary to this
+            model's properties, optionally checking that the keys exist.
+            '''
+        for k, v in adict.items():
+            if not transient:
+                assert hasattr(type(self), k), \
+                    "Model {} does not have a '{}' attribute.".format(
+                        type(self).__name__, k)
+            setattr(self, k, v)
+        return self
+
+    def update_from_schema(self, schema, adict):
+        '''Validates the information in the dictionary ``adict`` against
+            a Colander ``schema``. If validation fails, colander.Invalid
+            is raised. If happy, returns the updated model instance.
+            '''
+        schema._model_instance = self  # makes some validations easier
+        clean = schema.deserialize(adict)  # May raise colander.Invalid
+        self.update(clean)
+        return self
+
+    @classmethod
+    def query(cls, sas, *predicates, **filters):
+        return sas.query(cls).filter(*predicates).filter_by(**filters)
 
     @classmethod
     def get_or_create(cls, session, **filters):
